@@ -49,8 +49,6 @@ struct _GtkSourceCompletionModelClass {
 	GObjectClass parent_class;
 
 	void (*providers_changed) 	(GtkSourceCompletionModel *model);
-	void (*begin_delete)		(GtkSourceCompletionModel *model);
-	void (*end_delete)		(GtkSourceCompletionModel *model);
 };
 
 enum
@@ -70,22 +68,11 @@ G_GNUC_INTERNAL
 GtkSourceCompletionModel *
          gtk_source_completion_model_new			(void);
 
-G_GNUC_INTERNAL
-void     gtk_source_completion_model_begin_populate             (GtkSourceCompletionModel    *model,
-								 GList                       *providers);
-
 G_GNUC_INTERNAL
 void     gtk_source_completion_model_add_proposals              (GtkSourceCompletionModel    *model,
 								 GtkSourceCompletionProvider *provider,
 								 GList                       *proposals);
 
-G_GNUC_INTERNAL
-void     gtk_source_completion_model_end_populate               (GtkSourceCompletionModel    *model,
-								 GtkSourceCompletionProvider *provider);
-
-G_GNUC_INTERNAL
-void     gtk_source_completion_model_cancel			(GtkSourceCompletionModel    *model);
-
 G_GNUC_INTERNAL
 gboolean gtk_source_completion_model_is_empty			(GtkSourceCompletionModel    *model,
 								 gboolean                     only_visible);
@@ -104,9 +91,6 @@ G_GNUC_INTERNAL
 guint    gtk_source_completion_model_n_proposals		(GtkSourceCompletionModel    *model,
 								 GtkSourceCompletionProvider *provider);
 
-G_GNUC_INTERNAL
-void     gtk_source_completion_model_clear			(GtkSourceCompletionModel    *model);
-
 G_GNUC_INTERNAL
 void     gtk_source_completion_model_set_show_headers		(GtkSourceCompletionModel    *model,
 								 gboolean                     show_headers);
