@@ -32,6 +32,8 @@
 
 #include "gtksourceview-i18n.h"
 #include "gtksourceprintcompositor.h"
+#include "gtksourceview.h"
+#include "gtksourcebuffer.h"
 
 /**
  * SECTION:printcompositor
@@ -1138,8 +1140,8 @@ gtk_source_print_compositor_get_print_footer (GtkSourcePrintCompositor *composit
  * Sets strftime like header format strings, to be printed on the
  * left, center and right of the top of each page.  The strings may
  * include strftime(3) codes which will be expanded at print time.
- * All strftime() codes are accepted, with the addition of %N for the
- * page number and %Q for the page count.
+ * All strftime() codes are accepted, with the addition of #N for the
+ * page number and #Q for the page count.
  *
  * @separator specifies if a solid line should be drawn to separate
  * the header from the document text.
@@ -1189,8 +1191,8 @@ gtk_source_print_compositor_set_header_format (GtkSourcePrintCompositor *composi
  * Sets strftime like header format strings, to be printed on the
  * left, center and right of the bottom of each page. The strings may
  * include strftime(3) codes which will be expanded at print time.
- * All strftime() codes are accepted, with the addition of %N for the
- * page number and %Q for the page count.
+ * All strftime() codes are accepted, with the addition of #N for the
+ * page number and #Q for the page count.
  *
  * @separator specifies if a solid line should be drawn to separate
  * the footer from the document text.
