@@ -20,18 +20,16 @@
  */
 
 #include "gtksourcestyleschememanager.h"
-#include "gtksourcestylescheme.h"
+#include "gtksourceview-marshal.h"
 #include "gtksourceview-i18n.h"
 #include "gtksourceview-utils.h"
 #include <string.h>
 
 /**
  * SECTION:styleschememanager
- * @Short_description: Provides access to GtkSourceStyleSchemes
+ * @Short_description: Object which provides access to #GtkSourceStyleScheme<!-- -->s
  * @Title: GtkSourceStyleSchemeManager
  * @See_also: #GtkSourceStyleScheme
- *
- * Object which provides access to #GtkSourceStyleScheme<!-- -->s.
  */
 
 #define SCHEME_FILE_SUFFIX	".xml"
@@ -47,13 +45,15 @@ struct _GtkSourceStyleSchemeManagerPrivate
 	gchar          **ids; /* Cache the IDs of the available schemes */
 };
 
+
 enum {
 	PROP_0,
 	PROP_SEARCH_PATH,
 	PROP_SCHEME_IDS
 };
 
-G_DEFINE_TYPE_WITH_PRIVATE (GtkSourceStyleSchemeManager, gtk_source_style_scheme_manager, G_TYPE_OBJECT)
+
+G_DEFINE_TYPE (GtkSourceStyleSchemeManager, gtk_source_style_scheme_manager, G_TYPE_OBJECT)
 
 static void
 gtk_source_style_scheme_manager_set_property (GObject 	   *object,
@@ -149,24 +149,30 @@ gtk_source_style_scheme_manager_class_init (GtkSourceStyleSchemeManagerClass *kl
 	g_object_class_install_property (object_class,
 					 PROP_SEARCH_PATH,
 					 g_param_spec_boxed ("search-path",
-						 	     "Style scheme search path",
-							     "List of directories and files where the style schemes are located",
+						 	     _("Style scheme search path"),
+							     _("List of directories and files where the "
+							       "style schemes are located"),
 							     G_TYPE_STRV,
 							     G_PARAM_READWRITE));
 
 	g_object_class_install_property (object_class,
 					 PROP_SCHEME_IDS,
 					 g_param_spec_boxed ("scheme-ids",
-						 	     "Scheme ids",
-							     "List of the ids of the available style schemes",
+						 	     _("Scheme ids"),
+							     _("List of the ids of the available "
+							       "style schemes"),
 							     G_TYPE_STRV,
 							     G_PARAM_READABLE));
+
+	g_type_class_add_private (object_class, sizeof(GtkSourceStyleSchemeManagerPrivate));
 }
 
 static void
 gtk_source_style_scheme_manager_init (GtkSourceStyleSchemeManager *mgr)
 {
-	mgr->priv = gtk_source_style_scheme_manager_get_instance_private (mgr);
+	mgr->priv = G_TYPE_INSTANCE_GET_PRIVATE (mgr,
+						 GTK_SOURCE_TYPE_STYLE_SCHEME_MANAGER,
+						 GtkSourceStyleSchemeManagerPrivate);
 	mgr->priv->schemes_hash = NULL;
 	mgr->priv->ids = NULL;
 	mgr->priv->search_path = NULL;
@@ -360,7 +366,6 @@ reload_if_needed (GtkSourceStyleSchemeManager *mgr)
 			/* scheme with the same id already loaded from a path with higher prio: skip it */
 			if (g_hash_table_contains (schemes_hash, id))
 			{
-				g_object_unref (scheme);
 				continue;
 			}
 
@@ -541,9 +546,9 @@ gtk_source_style_scheme_manager_force_rescan (GtkSourceStyleSchemeManager *manag
  *
  * Returns the ids of the available style schemes.
  *
- * Returns: (nullable) (array zero-terminated=1) (transfer none):
- * a %NULL-terminated array of strings containing the ids of the available
- * style schemes or %NULL if no style scheme is available.
+ * Returns: (array zero-terminated=1) (transfer none): a %NULL-terminated array
+ * of string containing the ids of the available style schemes or %NULL if no
+ * style scheme is available.
  * The array is sorted alphabetically according to the scheme name.
  * The array is owned by the @manager and must not be modified.
  */
