@@ -26,15 +26,11 @@
 
 G_BEGIN_DECLS
 
-typedef struct _GtkSourceBufferInputStream	GtkSourceBufferInputStream;
-typedef struct _GtkSourceBufferOutputStream	GtkSourceBufferOutputStream;
-typedef struct _GtkSourceCompletionContainer	GtkSourceCompletionContainer;
 typedef struct _GtkSourceCompletionModel	GtkSourceCompletionModel;
 typedef struct _GtkSourceContextEngine		GtkSourceContextEngine;
 typedef struct _GtkSourceEngine			GtkSourceEngine;
 typedef struct _GtkSourceGutterRendererLines	GtkSourceGutterRendererLines;
 typedef struct _GtkSourceGutterRendererMarks	GtkSourceGutterRendererMarks;
-typedef struct _GtkSourceMarksSequence		GtkSourceMarksSequence;
 typedef struct _GtkSourcePixbufHelper		GtkSourcePixbufHelper;
 typedef struct _GtkSourceRegex			GtkSourceRegex;
 typedef struct _GtkSourceUndoManagerDefault	GtkSourceUndoManagerDefault;
