@@ -134,8 +134,6 @@ populate_model (GtkSourceCompletionModel *model,
 	GList *cur_provider;
 	GList *cur_list_proposals;
 
-	gtk_source_completion_model_begin_populate (model, all_providers);
-
 	for (cur_provider = all_providers,
 	     cur_list_proposals = all_list_proposals;
 	     cur_provider != NULL;
@@ -145,9 +143,6 @@ populate_model (GtkSourceCompletionModel *model,
 		gtk_source_completion_model_add_proposals (model,
 							   GTK_SOURCE_COMPLETION_PROVIDER (cur_provider->data),
 							   cur_list_proposals->data);
-
-		gtk_source_completion_model_end_populate (model,
-							  GTK_SOURCE_COMPLETION_PROVIDER (cur_provider->data));
 	}
 }
 
@@ -259,9 +254,7 @@ check_all_providers (GtkSourceCompletionModel *model,
 		g_assert (gtk_tree_model_iter_next (GTK_TREE_MODEL (model), &iter));
 	}
 
-#if 0
 	g_assert (!gtk_tree_model_iter_next (GTK_TREE_MODEL (model), &iter));
-#endif
 }
 
 static void
@@ -310,9 +303,7 @@ test_is_empty (void)
 	TestProvider *provider;
 	GList *list_providers = NULL;
 	GList *list_proposals = NULL;
-#if 0
 	GList *visible_providers = NULL;
-#endif
 
 	/* Completely empty */
 	model = gtk_source_completion_model_new ();
@@ -325,39 +316,24 @@ test_is_empty (void)
 	list_providers = g_list_append (list_providers, provider);
 	list_proposals = create_proposals ();
 
-	gtk_source_completion_model_begin_populate (model, list_providers);
-
 	gtk_source_completion_model_add_proposals (model,
 						   GTK_SOURCE_COMPLETION_PROVIDER (provider),
 						   list_proposals);
 
-	gtk_source_completion_model_end_populate (model,
-						  GTK_SOURCE_COMPLETION_PROVIDER (provider));
-
 	g_assert (!gtk_source_completion_model_is_empty (model, FALSE));
 	g_assert (!gtk_source_completion_model_is_empty (model, TRUE));
 
 	/* One invisible provider */
-
-	/* FIXME The two following tests are broken with the current implementation, it
-	 * will be fixed with the new implementation.
-	 * However it seems that this situation never happen, because if there is only one
-	 * invisible provider, the completion window is hidden.
-	 */
-#if 0
 	visible_providers = g_list_append (visible_providers, test_provider_new ());
 	gtk_source_completion_model_set_visible_providers (model, visible_providers);
 
 	g_assert (!gtk_source_completion_model_is_empty (model, FALSE));
 	g_assert (gtk_source_completion_model_is_empty (model, TRUE));
-#endif
 
 	g_object_unref (model);
 	g_list_free_full (list_providers, g_object_unref);
 	g_list_free_full (list_proposals, g_object_unref);
-#if 0
 	g_list_free_full (visible_providers, g_object_unref);
-#endif
 }
 
 static void
@@ -404,31 +380,6 @@ test_simple_populate (void)
 	free_providers (all_providers, all_list_proposals);
 }
 
-static void
-test_clear (void)
-{
-	GtkSourceCompletionModel *model;
-	GList *all_providers = NULL;
-	GList *all_list_proposals = NULL;
-
-	model = gtk_source_completion_model_new ();
-
-	/* Clear the model when it is already empty */
-	gtk_source_completion_model_clear (model);
-	g_assert (gtk_source_completion_model_is_empty (model, FALSE));
-
-	/* Add some proposals */
-	create_providers (&all_providers, &all_list_proposals);
-	populate_model (model, all_providers, all_list_proposals);
-
-	/* Clear the model when it is not empty */
-	gtk_source_completion_model_clear (model);
-	g_assert (gtk_source_completion_model_is_empty (model, FALSE));
-
-	g_object_unref (model);
-	free_providers (all_providers, all_list_proposals);
-}
-
 static void
 test_set_visible_providers (void)
 {
@@ -457,7 +408,6 @@ test_set_visible_providers (void)
 	subset_providers = g_list_append (subset_providers, all_providers->data);
 	subset_list_proposals = g_list_append (subset_list_proposals, all_list_proposals->data);
 
-#if 0
 	gtk_source_completion_model_set_visible_providers (model, subset_providers);
 	check_all_providers_with_and_without_headers (model, subset_providers, subset_list_proposals);
 
@@ -467,11 +417,9 @@ test_set_visible_providers (void)
 
 	gtk_source_completion_model_set_visible_providers (model, subset_providers);
 	check_all_providers_with_and_without_headers (model, subset_providers, subset_list_proposals);
-#endif
 
 	/* No visible providers */
 	other_provider = test_provider_new ();
-#if 0
 	subset_providers->data = other_provider;
 	gtk_source_completion_model_set_visible_providers (model, subset_providers);
 	g_assert (gtk_source_completion_model_is_empty (model, TRUE));
@@ -479,7 +427,6 @@ test_set_visible_providers (void)
 	/* The two providers are visible again */
 	gtk_source_completion_model_set_visible_providers (model, NULL);
 	check_all_providers_with_and_without_headers (model, all_providers, all_list_proposals);
-#endif
 
 	g_object_unref (model);
 	g_object_unref (other_provider);
@@ -488,84 +435,6 @@ test_set_visible_providers (void)
 	g_list_free (subset_list_proposals);
 }
 
-/* Do a first populate, and then a second populate with another set of
- * proposals. The proposals in common between the two populates are inserted in
- * the same order.
- */
-static void
-test_second_populate_same_order (void)
-{
-	GtkSourceCompletionModel *model;
-	GList *all_providers = NULL;
-	GList *all_list_proposals = NULL;
-	GList *list_proposals = NULL;
-
-	/* First populate with two providers */
-	model = gtk_source_completion_model_new ();
-	create_providers (&all_providers, &all_list_proposals);
-	populate_model (model, all_providers, all_list_proposals);
-
-	/* Remove the second provider and its associated proposals */
-	g_object_unref (all_providers->next->data);
-	all_providers = g_list_delete_link (all_providers, all_providers->next);
-
-	g_list_free_full (all_list_proposals->next->data, g_object_unref);
-	all_list_proposals = g_list_delete_link (all_list_proposals, all_list_proposals->next);
-
-	/* Alter the proposals of the remaining provider */
-	list_proposals = all_list_proposals->data;
-	g_object_unref (list_proposals->data);
-	list_proposals = g_list_delete_link (list_proposals, list_proposals);
-	list_proposals = g_list_concat (list_proposals, create_proposals ());
-	all_list_proposals->data = list_proposals;
-
-	/* Second populate */
-	populate_model (model, all_providers, all_list_proposals);
-	check_all_providers_with_and_without_headers (model, all_providers, all_list_proposals);
-
-	g_object_unref (model);
-	free_providers (all_providers, all_list_proposals);
-}
-
-#if 0
-/* Same as test_second_populate_same_order() but with a different insertion
- * order of the common proposals for the second populate.
- */
-static void
-test_second_populate_different_order (void)
-{
-	GtkSourceCompletionModel *model;
-	GList *all_providers = NULL;
-	GList *all_list_proposals = NULL;
-	GList *list_proposals = NULL;
-
-	/* First populate with two providers */
-	model = gtk_source_completion_model_new ();
-	create_providers (&all_providers, &all_list_proposals);
-	populate_model (model, all_providers, all_list_proposals);
-
-	/* Remove the second provider and its associated proposals */
-	g_object_unref (all_providers->next->data);
-	all_providers = g_list_delete_link (all_providers, all_providers->next);
-
-	g_list_free_full (all_list_proposals->next->data, g_object_unref);
-	all_list_proposals = g_list_delete_link (all_list_proposals, all_list_proposals->next);
-
-	/* Alter the proposals of the remaining provider */
-	list_proposals = all_list_proposals->data;
-	list_proposals = g_list_reverse (list_proposals);
-	list_proposals = g_list_concat (list_proposals, create_proposals ());
-	all_list_proposals->data = list_proposals;
-
-	/* Second populate */
-	populate_model (model, all_providers, all_list_proposals);
-	check_all_providers_with_and_without_headers (model, all_providers, all_list_proposals);
-
-	g_object_unref (model);
-	free_providers (all_providers, all_list_proposals);
-}
-#endif
-
 static void
 test_populate_several_batches (void)
 {
@@ -578,7 +447,6 @@ test_populate_several_batches (void)
 	GtkTreeIter iter;
 
 	gtk_source_completion_model_set_show_headers (model, TRUE);
-	gtk_source_completion_model_begin_populate (model, list_providers);
 
 	/* First batch */
 	gtk_source_completion_model_add_proposals (model, provider, first_proposals);
@@ -589,7 +457,6 @@ test_populate_several_batches (void)
 
 	/* Second batch */
 	gtk_source_completion_model_add_proposals (model, provider, second_proposals);
-	gtk_source_completion_model_end_populate (model, provider);
 
 	all_proposals = g_list_copy (first_proposals);
 	all_proposals = g_list_concat (all_proposals, g_list_copy (second_proposals));
@@ -626,6 +493,7 @@ test_get_providers (void)
 
 	g_object_unref (model);
 	free_providers (all_providers, all_list_proposals);
+	g_list_free (providers_get);
 }
 
 static void
@@ -645,9 +513,7 @@ test_n_proposals (void)
 	list_providers = g_list_append (NULL, provider);
 	list_proposals = create_proposals ();
 
-	gtk_source_completion_model_begin_populate (model, list_providers);
 	gtk_source_completion_model_add_proposals (model, provider, list_proposals);
-	gtk_source_completion_model_end_populate (model, provider);
 
 	g_assert (gtk_source_completion_model_n_proposals (model, other_provider) == 0);
 
@@ -684,10 +550,7 @@ test_iters_impl (gboolean show_headers)
 	gint *indices;
 
 	/* Test iter_last() */
-#if 0
-	/* segfault */
 	g_assert (!gtk_source_completion_model_iter_last (model, &last_iter));
-#endif
 
 	create_providers (&all_providers, &all_list_proposals);
 	populate_model (model, all_providers, all_list_proposals);
@@ -737,50 +600,47 @@ static void
 test_iters (void)
 {
 	test_iters_impl (FALSE);
-#if 0
 	test_iters_impl (TRUE);
-#endif
 }
 
 static void
-test_cancel (void)
+on_row_changed (GtkTreeModel                *model,
+		GtkTreePath                 *path,
+		GtkTreeIter                 *iter,
+		GtkSourceCompletionProposal *proposal)
+{
+	GtkSourceCompletionProposal *row_proposal = NULL;
+
+	gtk_tree_model_get (model, iter,
+			    GTK_SOURCE_COMPLETION_MODEL_COLUMN_PROPOSAL, &row_proposal,
+			    -1);
+
+	/* Make sure that the signal was emitted for the good row. */
+	g_assert (proposal == row_proposal);
+}
+
+static void
+test_row_changed (void)
 {
 	GtkSourceCompletionModel *model = gtk_source_completion_model_new ();
-	GtkSourceCompletionProvider *provider;
-	GList *list_providers = NULL;
-	GList *proposals = NULL;
-	GList *all_providers = NULL;
-	GList *all_list_proposals = NULL;
+	TestProvider *provider = test_provider_new ();
+	GList *proposals = create_proposals ();
+	GtkSourceCompletionProposal *proposal = proposals->data;
 
-	/* Cancel out of a population, when the model is empty */
-	gtk_source_completion_model_cancel (model);
-	g_assert (gtk_source_completion_model_is_empty (model, FALSE));
+	gtk_source_completion_model_add_proposals (model,
+						   GTK_SOURCE_COMPLETION_PROVIDER (provider),
+						   proposals);
 
-	/* Cancel during a population.
-	 * The contents of the model after the cancellation depends on the
-	 * implementation. Thus we don't check the contents.
-	 */
-	provider = GTK_SOURCE_COMPLETION_PROVIDER (test_provider_new ());
-	proposals = create_proposals ();
-	list_providers = g_list_append (NULL, provider);
+	g_signal_connect (model,
+			  "row-changed",
+			  G_CALLBACK (on_row_changed),
+			  proposal);
 
-	gtk_source_completion_model_begin_populate (model, list_providers);
-	gtk_source_completion_model_add_proposals (model, provider, proposals);
-	gtk_source_completion_model_cancel (model);
-
-	/* Normal population */
-	create_providers (&all_providers, &all_list_proposals);
-	populate_model (model, all_providers, all_list_proposals);
-	check_all_providers_with_and_without_headers (model, all_providers, all_list_proposals);
-
-	/* Cancel out of a population, when the model is not empty */
-	gtk_source_completion_model_cancel (model);
-	check_all_providers_with_and_without_headers (model, all_providers, all_list_proposals);
+	gtk_source_completion_proposal_changed (proposal);
 
 	g_object_unref (model);
-	g_list_free_full (list_providers, g_object_unref);
+	g_object_unref (provider);
 	g_list_free_full (proposals, g_object_unref);
-	free_providers (all_providers, all_list_proposals);
 }
 
 int
@@ -797,20 +657,9 @@ main (int argc, char **argv)
 	g_test_add_func ("/CompletionModel/simple-populate",
 			 test_simple_populate);
 
-	g_test_add_func ("/CompletionModel/clear",
-			 test_clear);
-
 	g_test_add_func ("/CompletionModel/set-visible-providers",
 			 test_set_visible_providers);
 
-	g_test_add_func ("/CompletionModel/second-populate-same-order",
-			 test_second_populate_same_order);
-
-#if 0
-	g_test_add_func ("/CompletionModel/second-populate-different-order",
-			 test_second_populate_different_order);
-#endif
-
 	g_test_add_func ("/CompletionModel/populate-several-batches",
 			 test_populate_several_batches);
 
@@ -823,8 +672,8 @@ main (int argc, char **argv)
 	g_test_add_func ("/CompletionModel/iters",
 			 test_iters);
 
-	g_test_add_func ("/CompletionModel/cancel",
-			 test_cancel);
+	g_test_add_func ("/CompletionModel/row-changed",
+			 test_row_changed);
 
 	return g_test_run ();
 }
